
/******************************************************************************
 * @file     init.c
 * @brief    Interrupts Vector Table and Clock and PLL initialization
 * @version  V2.00
 * @date     17. June 2015
 ******************************************************************************/
 
#include "lpc11E13.h"

void init(void);
//void NMI_interrupt(void);
//void Hard_Fault_interrupt(void);
//void SVCall_interrupt(void);
//void PendSV_interrupt(void);
//void SysTic_interrupt(void);
void PIN_INT0_interrupt(void);
//void PIN_INT1_interrupt(void);
//void PIN_INT2_interrupt(void);
//void PIN_INT3_interrupt(void);
//void PIN_INT4_interrupt(void);
//void PIN_INT5_interrupt(void);
//void PIN_INT6_interrupt(void);
//void PIN_INT7_interrupt(void);
//void GINT0_interrupt(void);
//void GINT1_interrupt(void);
void Default_Handler(void);
//void SSP1_interrupt(void);
//void I2C_interrupt(void);
void CT16B0_interrupt(void);
//void CT16B1_interrupt(void);
//void CT32B0_interrupt(void);
//void CT32B1_interrupt(void);
//void SSP0_interrupt(void);
void USART_interrupt(void);
//void ADC_interrupt(void);
//void WWDT_interrupt(void);
//void BOD_interrupt(void);
//void FLASH_EEPROM_interrupt(void);
//void IOH_interrupt(void);

// The following are 'declared' in the linker script
extern unsigned char  INIT_DATA_VALUES;
extern unsigned char  INIT_DATA_START;
extern unsigned char  INIT_DATA_END;
extern unsigned char  BSS_START;
extern unsigned char  BSS_END;

// The section "vectors" is placed at the beginning of flash by the linker script
const void * Vectors[] __attribute__((section(".vectors"))) =
{
	(void *)0x10002000, 	/* Top of stack */ 
	init,   				/* Reset Handler */
	Default_Handler,									//NMI_interrupt,			/* NMI */
	Default_Handler,									//Hard_Fault_interrupt,		/* Hard Fault */
	0,	                	/* Reserved */
	0,                   	/* Reserved */
	0,                   	/* Reserved */
	0,                   	/* Reserved */
	0,                   	/* Reserved */
	0,                   	/* Reserved */
	0,                   	/* Reserved */
	Default_Handler,									//SVCall_interrupt,			/* SVC */
	0,                   	/* Reserved */
	0,                   	/* Reserved */
	Default_Handler,									//PendSV_interrupt,     	/* PendSV */
	Default_Handler,									//SysTic_interrupt,     	/* SysTick */
	
/* External interrupt handlers follow */

	PIN_INT0_interrupt, 	/* GPIO pin interrupt 0 (0) */
	Default_Handler,									//PIN_INT1_interrupt,		/* GPIO pin interrupt 1  (1)  */
	Default_Handler,									//PIN_INT2_interrupt,		/* GPIO pin interrupt 2  (2)  */
	Default_Handler,									//PIN_INT3_interrupt,		/* GPIO pin interrupt 3  (3)  */
	Default_Handler,									//PIN_INT4_interrupt,		/* GPIO pin interrupt 4  (4)  */
	Default_Handler,									//PIN_INT5_interrupt,		/* GPIO pin interrupt 5  (5)  */
	Default_Handler,									//PIN_INT6_interrupt,		/* GPIO pin interrupt 6  (6)  */
	Default_Handler,									//PIN_INT7_interrupt,		/* GPIO pin interrupt 7  (7)  */
	Default_Handler,									//GINT0_interrupt,			/* GPIO GROUP0 interrupt (8)  */
	Default_Handler,									//GINT1_interrupt,			/* GPIO GROUP0 interrupt (9)  */
	Default_Handler, 		/* RESERVED (10) */
	Default_Handler, 		/* RESERVED (11) */
	Default_Handler,		/* RESERVED (12) */
	Default_Handler,  		/* RESERVED (13) */
	Default_Handler,									//SSP1_interrupt, 			/* SSP1 interrupt   	 (14) */
	Default_Handler,									//I2C_interrupt, 			/* I2C interrupt  	     (15) */
	CT16B0_interrupt, 		/* CT16B0 interrupt (16) */
	Default_Handler,									//CT16B1_interrupt, 		/* CT16B1 interrupt 	 (17) */
	Default_Handler,									//CT32B0_interrupt, 		/* CT32B0 interrupt 	 (18) */
	Default_Handler,									//CT32B1_interrupt, 		/* CT32B1 interrupt 	 (19) */
	Default_Handler,									//SSP0_interrupt, 			/* SSP0 interrupt   	 (20) */
	USART_interrupt,		/* UART interrupt (21) */
	Default_Handler, 		/* RESERVED (22) */
	Default_Handler, 		/* RESERVED (23) */
	Default_Handler,									//ADC_interrupt, 			/* ADC interrupt   		 (24) */
	Default_Handler,									//WWDT_interrupt, 			/* WDT interrupt    	 (25) */
	Default_Handler,									//BOD_interrupt, 			/* BOD interrupt    	 (26) */
	Default_Handler,									//FLASH_EEPROM_interrupt, 	/* Flash/EEPROM interrupt(27) */
	Default_Handler, 		/* RESERVED (28) */
	Default_Handler, 		/* RESERVED (29) */
	Default_Handler, 		/* RESERVED (30) */
	Default_Handler,									//IOH_interrupt 			/* I/O Handler interrupt (31) */
};

extern inline clock_init()
{
	// This function sets the main clock to the PLL
	// The PLL input is the built in 12MHz RC oscillator
	// This is multiplied up to 48MHz for the main clock (MSEL = 3, PSEL = 1)
	
	SYSPLLCLKSEL = 0; 					// select internal RC oscillator
	SYSPLLCTRL = 3 | (1 << 5); 			// set divisors/multipliers
	MAINCLKSEL = 3; 					// Use PLL output as main clock
	PDRUNCFG &= ~(1<<7); 				// Power up the PLL. This MUST be done before update ~xxUEN registers
	SYSPLLCLKUEN = 0; 					// inform PLL of update
	SYSPLLCLKUEN = 1; 	
	MAINCLKUEN = 0; 					// Inform core of clock update
	MAINCLKUEN = 1;	
	while(!(SYSPLLSTAT & 1));			//Wait until PLL is locked
}

void init()
{
	// do global/static data initialization
	unsigned char *src;
	unsigned char *dest;
	unsigned len;
	src= &INIT_DATA_VALUES;
	dest= &INIT_DATA_START;
	len= &INIT_DATA_END-&INIT_DATA_START;
	while (len--)
		*dest++ = *src++;
		
	// zero out the uninitialized global/static variables
	dest = &BSS_START;
	len = &BSS_END - &BSS_START;
	while (len--)
		*dest++=0;
		
	clock_init();
	main();
}

void Default_Handler()
{
	_printf("\nDefault Handler. -Halt-\n");
	while(1);
}
