
/******************************************************************************
 * @file     lpc11E13.h
 * @brief    Cortex-M0 Core Header File for NXP LPC11E13 Device Series
 * @version  V1.00
 * @date     17. December 2014
 ******************************************************************************/

/*
 * ==========================================================================
 * ----------- Processor and Core Peripheral Section ------------------------
 * ==========================================================================
 */

#define  REGISTER_32(ADDRESS) (*((volatile unsigned long *)(ADDRESS)))
#define  REGISTER_8(ADDRESS)  (*((volatile unsigned char *)(ADDRESS)))

/******************************************************************************/
/*                         Peripheral memory map                              */
/******************************************************************************/

#define LPC_I2C_BASE              	(0x40000000)
#define LPC_WWDT_BASE             	(0x40004000)
#define LPC_USART_BASE            	(0x40008000)
#define LPC_CT16B0_BASE           	(0x4000C000)
#define LPC_CT16B1_BASE           	(0x40010000)
#define LPC_CT32B0_BASE           	(0x40014000)
#define LPC_CT32B1_BASE           	(0x40018000)
#define LPC_ADC_BASE              	(0x4001C000)
#define LPC_PMU_BASE              	(0x40038000)
#define LPC_FLASH_EEPROM_CTRL_BASE	(0x4003C000)
#define LPC_SSP0_BASE             	(0x40040000)
#define LPC_SSP1_BASE             	(0x40058000)
#define LPC_IOCON_BASE            	(0x40044000)
#define LPC_SYSCON_BASE           	(0x40048000)
#define LPC_GPIO_PIN_INT_BASE     	(0x4004C000)
#define LPC_GPIO_GROUP_INT0_BASE  	(0x4005C000)
#define LPC_GPIO_GROUP_INT1_BASE  	(0x40060000)
#define LPC_GPIO_BASE             	(0x50000000)
#define LPC_NVIC_BASE             	(0xE000E000) 

/******************************************************************************/
/*                Device Specific Peripheral Registers                        */
/******************************************************************************/

/*------------- System Control (SYSCON) --------------------------------------*/
                           
#define SYSMEMREMAP            REGISTER_32(LPC_SYSCON_BASE + 0x000)    			   /*!< (@ 0x000) System memory remap    */
#define PRESETCTRL             REGISTER_32(LPC_SYSCON_BASE + 0x004)    			   /*!< (@ 0x004) Peripheral reset control */
#define SYSPLLCTRL             REGISTER_32(LPC_SYSCON_BASE + 0x008)    			   /*!< (@ 0x008) System PLL control     */
#define SYSPLLSTAT             REGISTER_32(LPC_SYSCON_BASE + 0x00C)    			   /*!< (@ 0x00C) System PLL status      */
          			                                           
#define SYSOSCCTRL             REGISTER_32(LPC_SYSCON_BASE + 0x020)    			   /*!< (@ 0x020) System oscillator control */
#define WDTOSCCTRL             REGISTER_32(LPC_SYSCON_BASE + 0x024)    			   /*!< (@ 0x024) Watchdog oscillator control */
         			                                           
#define SYSRSTSTAT             REGISTER_32(LPC_SYSCON_BASE + 0x030)    			   /*!< (@ 0x030) System reset status register */
           			                                           
#define SYSPLLCLKSEL           REGISTER_32(LPC_SYSCON_BASE + 0x040)    			   /*!< (@ 0x040) System PLL clock source select */
#define SYSPLLCLKUEN           REGISTER_32(LPC_SYSCON_BASE + 0x044)    			   /*!< (@ 0x044) System PLL clock source update enable */
         			                                           
#define MAINCLKSEL             REGISTER_32(LPC_SYSCON_BASE + 0x070)    			   /*!< (@ 0x070) Main clock source select */
#define MAINCLKUEN             REGISTER_32(LPC_SYSCON_BASE + 0x074)    			   /*!< (@ 0x074) Main clock source update enable */
#define SYSAHBCLKDIV           REGISTER_32(LPC_SYSCON_BASE + 0x078)    			   /*!< (@ 0x078) System clock divider   */
         			                                           
#define SYSAHBCLKCTRL          REGISTER_32(LPC_SYSCON_BASE + 0x080)    			   /*!< (@ 0x080) System clock control   */
          			                                           
#define SSP0CLKDIV             REGISTER_32(LPC_SYSCON_BASE + 0x094)    			   /*!< (@ 0x094) SSP0 clock divider     */
#define UARTCLKDIV             REGISTER_32(LPC_SYSCON_BASE + 0x098)    			   /*!< (@ 0x098) UART clock divider     */
#define SSP1CLKDIV             REGISTER_32(LPC_SYSCON_BASE + 0x09C)    			   /*!< (@ 0x09C) SSP1 clock divider     */
       			                                           
#define CLKOUTSEL              REGISTER_32(LPC_SYSCON_BASE + 0x0E0)    			   /*!< (@ 0x0E0) CLKOUT clock source select */
#define CLKOUTUEN              REGISTER_32(LPC_SYSCON_BASE + 0x0E4)    			   /*!< (@ 0x0E4) CLKOUT clock source update enable */
#define CLKOUTDIV              REGISTER_32(LPC_SYSCON_BASE + 0x0E8)    			   /*!< (@ 0x0E8) CLKOUT clock divider   */
       			                                           
#define PIOPORCAP0             REGISTER_32(LPC_SYSCON_BASE + 0x100)    			   /*!< (@ 0x100) POR captured PIO status 0 */
#define PIOPORCAP1             REGISTER_32(LPC_SYSCON_BASE + 0x104)    			   /*!< (@ 0x104) POR captured PIO status 1 */
        			                                           
#define BODCTRL                REGISTER_32(LPC_SYSCON_BASE + 0x150)    			   /*!< (@ 0x150) Brown-Out Detect       */
#define SYSTCKCAL              REGISTER_32(LPC_SYSCON_BASE + 0x154)    			   /*!< (@ 0x154) System tick counter calibration */
        		                                               
#define IRQLATENCY             REGISTER_32(LPC_SYSCON_BASE + 0x170)    			   /*!< (@ 0x170) IQR delay */
#define NMISRC                 REGISTER_32(LPC_SYSCON_BASE + 0x174)    			   /*!< (@ 0x174) NMI Source Control     */
#define PINTSEL0               REGISTER_32(LPC_SYSCON_BASE + 0x178)    			   /*!< (@ 0x178) GPIO Pin Interrupt Select register 0 */
#define PINTSEL1               REGISTER_32(LPC_SYSCON_BASE + 0x17C)    			   /*!< (@ 0x178) GPIO Pin Interrupt Select register 1 */
#define PINTSEL2               REGISTER_32(LPC_SYSCON_BASE + 0x180)    			   /*!< (@ 0x178) GPIO Pin Interrupt Select register 2 */
#define PINTSEL3               REGISTER_32(LPC_SYSCON_BASE + 0x184)    			   /*!< (@ 0x178) GPIO Pin Interrupt Select register 3 */
#define PINTSEL4               REGISTER_32(LPC_SYSCON_BASE + 0x188)    			   /*!< (@ 0x178) GPIO Pin Interrupt Select register 4 */
#define PINTSEL5               REGISTER_32(LPC_SYSCON_BASE + 0x18C)    			   /*!< (@ 0x178) GPIO Pin Interrupt Select register 5 */
#define PINTSEL6               REGISTER_32(LPC_SYSCON_BASE + 0x190)    			   /*!< (@ 0x178) GPIO Pin Interrupt Select register 6 */
#define PINTSEL7               REGISTER_32(LPC_SYSCON_BASE + 0x194)    			   /*!< (@ 0x178) GPIO Pin Interrupt Select register 7 */
       			                                           
#define STARTERP0              REGISTER_32(LPC_SYSCON_BASE + 0x204)    			   /*!< (@ 0x204) Start logic 0 interrupt wake-up enable register 0 */
         		                                               
#define STARTERP1              REGISTER_32(LPC_SYSCON_BASE + 0x214)    			   /*!< (@ 0x214) Start logic 1 interrupt wake-up enable register 1 */
         			                                           
#define PDSLEEPCFG             REGISTER_32(LPC_SYSCON_BASE + 0x230)    			   /*!< (@ 0x230) Power-down states in deep-sleep mode */
#define PDAWAKECFG             REGISTER_32(LPC_SYSCON_BASE + 0x234)    			   /*!< (@ 0x234) Power-down states for wake-up from deep-sleep */
#define PDRUNCFG               REGISTER_32(LPC_SYSCON_BASE + 0x238)    			   /*!< (@ 0x238) Power configuration register */
        		                                               
#define DEVICE_ID              REGISTER_32(LPC_SYSCON_BASE + 0x3F4)    			   /*!< (@ 0x3F4) Device ID              */

/*------------- Pin Connect Block (IOCON) --------------------------------*/
                          
#define RESET_PIO0_0           REGISTER_32(LPC_IOCON_BASE + 0x000)    			   /*!< (@ 0x000) I/O configuration for pin RESET/PIO0_0 */
#define PIO0_1                 REGISTER_32(LPC_IOCON_BASE + 0x004)    			   /*!< (@ 0x004) I/O configuration for pin PIO0_1/CLKOUT/CT32B0_MAT2 */
#define PIO0_2                 REGISTER_32(LPC_IOCON_BASE + 0x008)    			   /*!< (@ 0x008) I/O configuration for pin PIO0_2/SSEL0/CT16B0_CAP0 */
#define PIO0_3                 REGISTER_32(LPC_IOCON_BASE + 0x00C)    			   /*!< (@ 0x00C) I/O configuration for pin PIO0_3 */
#define PIO0_4                 REGISTER_32(LPC_IOCON_BASE + 0x010)    			   /*!< (@ 0x010) I/O configuration for pin PIO0_4/SCL */
#define PIO0_5                 REGISTER_32(LPC_IOCON_BASE + 0x014)    			   /*!< (@ 0x014) I/O configuration for pin PIO0_5/SDA */
#define PIO0_6                 REGISTER_32(LPC_IOCON_BASE + 0x018)    			   /*!< (@ 0x018) I/O configuration for pin PIO0_6/SCK0 */
#define PIO0_7                 REGISTER_32(LPC_IOCON_BASE + 0x01C)    			   /*!< (@ 0x01C) I/O configuration for pin PIO0_7/CTS */
#define PIO0_8                 REGISTER_32(LPC_IOCON_BASE + 0x020)    			   /*!< (@ 0x020) I/O configuration for pin PIO0_8/MISO0/CT16B0_MAT0 */
#define PIO0_9                 REGISTER_32(LPC_IOCON_BASE + 0x024)    			   /*!< (@ 0x024) I/O configuration for pin PIO0_9/MOSI0/CT16B0_MAT1 */
#define SWCLK_PIO0_10          REGISTER_32(LPC_IOCON_BASE + 0x028)    			   /*!< (@ 0x028) I/O configuration for pin SWCLK/PIO0_10/ SCK0/CT16B0_MAT2 */
#define TDI_PIO0_11            REGISTER_32(LPC_IOCON_BASE + 0x02C)    			   /*!< (@ 0x02C) I/O configuration for pin TDI/PIO0_11/AD0/CT32B0_MAT3 */
#define TMS_PIO0_12            REGISTER_32(LPC_IOCON_BASE + 0x030)    			   /*!< (@ 0x030) I/O configuration for pin TMS/PIO0_12/AD1/CT32B1_CAP0 */
#define TDO_PIO0_13            REGISTER_32(LPC_IOCON_BASE + 0x034)    			   /*!< (@ 0x034) I/O configuration for pin TDO/PIO0_13/AD2/CT32B1_MAT0 */
#define TRST_PIO0_14           REGISTER_32(LPC_IOCON_BASE + 0x038)    			   /*!< (@ 0x038) I/O configuration for pin TRST/PIO0_14/AD3/CT32B1_MAT1 */
#define SWDIO_PIO0_15          REGISTER_32(LPC_IOCON_BASE + 0x03C)    			   /*!< (@ 0x03C) I/O configuration for pin SWDIO/PIO0_15/AD4/CT32B1_MAT2 */
#define PIO0_16                REGISTER_32(LPC_IOCON_BASE + 0x040)    			   /*!< (@ 0x040) I/O configuration for pin PIO0_16/AD5/CT32B1_MAT3/ WAKEUP */
#define PIO0_17                REGISTER_32(LPC_IOCON_BASE + 0x044)    			   /*!< (@ 0x044) I/O configuration for pin PIO0_17/RTS/CT32B0_CAP0/SCLK */
#define PIO0_18                REGISTER_32(LPC_IOCON_BASE + 0x048)    			   /*!< (@ 0x048) I/O configuration for pin PIO0_18/RXD/CT32B0_MAT0 */
#define PIO0_19                REGISTER_32(LPC_IOCON_BASE + 0x04C)    			   /*!< (@ 0x04C) I/O configuration for pin PIO0_19/TXD/CT32B0_MAT1 */
#define PIO0_20                REGISTER_32(LPC_IOCON_BASE + 0x050)    			   /*!< (@ 0x050) I/O configuration for pin PIO0_20/CT16B1_CAP0 */
#define PIO0_21                REGISTER_32(LPC_IOCON_BASE + 0x054)    			   /*!< (@ 0x054) I/O configuration for pin PIO0_21/CT16B1_MAT0/MOSI1 */
#define PIO0_22                REGISTER_32(LPC_IOCON_BASE + 0x058)    			   /*!< (@ 0x058) I/O configuration for pin PIO0_22/AD6/CT16B1_MAT1/MISO1 */
#define PIO0_23                REGISTER_32(LPC_IOCON_BASE + 0x05C)    			   /*!< (@ 0x05C) I/O configuration for pin PIO0_23/AD7 */
	                                                                               
#define PIO1_13                REGISTER_32(LPC_IOCON_BASE + 0x094)    			   /*!< (@ 0x094) I/O configuration for pin PIO1_13/DTR/CT16B0_MAT0/TXD */
#define PIO1_14                REGISTER_32(LPC_IOCON_BASE + 0x098)    			   /*!< (@ 0x098) I/O configuration for pin PIO1_14/DSR/CT16B0_MAT1/RXD */
#define PIO1_15                REGISTER_32(LPC_IOCON_BASE + 0x09C)    			   /*!< (@ 0x09C) I/O configuration for pin PIO1_15/DCD/ CT16B0_MAT2/SCK1 */
#define PIO1_16                REGISTER_32(LPC_IOCON_BASE + 0x0A0)    			   /*!< (@ 0x0A0) I/O configuration for pin PIO1_16/RI/CT16B0_CAP0 */
			                                                                       
#define PIO1_19                REGISTER_32(LPC_IOCON_BASE + 0x0AC)    			   /*!< (@ 0x0AC) I/O configuration for pin PIO1_19/DTR/SSEL1 */
#define PIO1_20                REGISTER_32(LPC_IOCON_BASE + 0x0B0)    			   /*!< (@ 0x0B0) I/O configuration for pin PIO1_20/DSR/SCK1 */
#define PIO1_21                REGISTER_32(LPC_IOCON_BASE + 0x0B4)    			   /*!< (@ 0x0B4) I/O configuration for pin PIO1_21/DCD/MISO1 */
#define PIO1_22                REGISTER_32(LPC_IOCON_BASE + 0x0B8)    			   /*!< (@ 0x0B8) I/O configuration for pin PIO1_22/RI/MOSI1 */
#define PIO1_23                REGISTER_32(LPC_IOCON_BASE + 0x0BC)    			   /*!< (@ 0x0BC) I/O configuration for pin PIO1_23/CT16B1_MAT1/SSEL1 */
#define PIO1_24                REGISTER_32(LPC_IOCON_BASE + 0x0C0)    			   /*!< (@ 0x0C0) I/O configuration for pin PIO1_24/ CT32B0_MAT0 */
#define PIO1_25                REGISTER_32(LPC_IOCON_BASE + 0x0C4)    			   /*!< (@ 0x0C4) I/O configuration for pin PIO1_25/CT32B0_MAT1 */
#define PIO1_26                REGISTER_32(LPC_IOCON_BASE + 0x0C8)    			   /*!< (@ 0x0C8) I/O configuration for pin PIO1_26/CT32B0_MAT2/ RXD */
#define PIO1_27                REGISTER_32(LPC_IOCON_BASE + 0x0CC)    			   /*!< (@ 0x0CC) I/O configuration for pin PIO1_27/CT32B0_MAT3/ TXD */
#define PIO1_28                REGISTER_32(LPC_IOCON_BASE + 0x0D0)    			   /*!< (@ 0x0D0) I/O configuration for pin PIO1_28/CT32B0_CAP0/ SCLK */
#define PIO1_29                REGISTER_32(LPC_IOCON_BASE + 0x0D4)    			   /*!< (@ 0x0D4) I/O configuration for pin PIO1_29/SCK0/ CT32B0_CAP1 */
	
#define PIO1_31                REGISTER_32(LPC_IOCON_BASE + 0x0DC)    			   /*!< (@ 0x0DC) I/O configuration for pin PIO1_31 */

/*------------- Power Management Unit (PMU) --------------------------*/
                       
#define PCON                   REGISTER_32(LPC_PMU_BASE + 0x000)    			   /*!< (@ 0x000) Power control register */
				                                                                   
#define GPREG0                 REGISTER_32(LPC_PMU_BASE + 0x004)    			   /*!< (@ 0x004) General purpose register 0 */
#define GPREG1                 REGISTER_32(LPC_PMU_BASE + 0x008)    			   /*!< (@ 0x008) General purpose register 1 */
#define GPREG2                 REGISTER_32(LPC_PMU_BASE + 0x00C)    			   /*!< (@ 0x00C) General purpose register 2 */
#define GPREG3                 REGISTER_32(LPC_PMU_BASE + 0x010)    			   /*!< (@ 0x010) General purpose register 3 */

/*------------- General Purpose Input/Output (GPIO) --------------------------*/

#define B0_0                   REGISTER_8(LPC_GPIO_BASE + 0x0000) 				   /*!< (@ 0x0000) Byte pin registers port 0 pin PIO0_0 */
#define B0_1				   REGISTER_8(LPC_GPIO_BASE + 0x0001)				   /*!< (@ 0x0001) Byte pin registers port 0 pin PIO0_1 */
#define B0_2				   REGISTER_8(LPC_GPIO_BASE + 0x0002)				   /*!< (@ 0x0002) Byte pin registers port 0 pin PIO0_2 */
#define B0_3				   REGISTER_8(LPC_GPIO_BASE + 0x0003)				   /*!< (@ 0x0003) Byte pin registers port 0 pin PIO0_3 */
#define B0_4				   REGISTER_8(LPC_GPIO_BASE + 0x0004)				   /*!< (@ 0x0004) Byte pin registers port 0 pin PIO0_4 */
#define B0_5				   REGISTER_8(LPC_GPIO_BASE + 0x0005)				   /*!< (@ 0x0005) Byte pin registers port 0 pin PIO0_5 */
#define B0_6				   REGISTER_8(LPC_GPIO_BASE + 0x0006)				   /*!< (@ 0x0006) Byte pin registers port 0 pin PIO0_6 */
#define B0_7				   REGISTER_8(LPC_GPIO_BASE + 0x0007)				   /*!< (@ 0x0007) Byte pin registers port 0 pin PIO0_7 */
#define B0_8				   REGISTER_8(LPC_GPIO_BASE + 0x0008)				   /*!< (@ 0x0008) Byte pin registers port 0 pin PIO0_8 */
#define B0_9				   REGISTER_8(LPC_GPIO_BASE + 0x0009)				   /*!< (@ 0x0009) Byte pin registers port 0 pin PIO0_9 */
#define B0_10				   REGISTER_8(LPC_GPIO_BASE + 0x000A)				   /*!< (@ 0x000A) Byte pin registers port 0 pin PIO0_10 */
#define B0_11				   REGISTER_8(LPC_GPIO_BASE + 0x000B)				   /*!< (@ 0x000B) Byte pin registers port 0 pin PIO0_11 */
#define B0_12				   REGISTER_8(LPC_GPIO_BASE + 0x000C)				   /*!< (@ 0x000C) Byte pin registers port 0 pin PIO0_12 */
#define B0_13				   REGISTER_8(LPC_GPIO_BASE + 0x000D)				   /*!< (@ 0x000D) Byte pin registers port 0 pin PIO0_13 */
#define B0_14				   REGISTER_8(LPC_GPIO_BASE + 0x000E)				   /*!< (@ 0x000E) Byte pin registers port 0 pin PIO0_14 */
#define B0_15				   REGISTER_8(LPC_GPIO_BASE + 0x000F)				   /*!< (@ 0x000F) Byte pin registers port 0 pin PIO0_15 */
#define B0_16				   REGISTER_8(LPC_GPIO_BASE + 0x0010)				   /*!< (@ 0x0010) Byte pin registers port 0 pin PIO0_16 */
#define B0_17				   REGISTER_8(LPC_GPIO_BASE + 0x0011)				   /*!< (@ 0x0011) Byte pin registers port 0 pin PIO0_17 */
#define B0_18				   REGISTER_8(LPC_GPIO_BASE + 0x0012)				   /*!< (@ 0x0012) Byte pin registers port 0 pin PIO0_18 */
#define B0_19				   REGISTER_8(LPC_GPIO_BASE + 0x0013)				   /*!< (@ 0x0013) Byte pin registers port 0 pin PIO0_19 */
#define B0_20				   REGISTER_8(LPC_GPIO_BASE + 0x0014)				   /*!< (@ 0x0014) Byte pin registers port 0 pin PIO0_20 */
#define B0_21				   REGISTER_8(LPC_GPIO_BASE + 0x0015)				   /*!< (@ 0x0015) Byte pin registers port 0 pin PIO0_21 */
#define B0_22				   REGISTER_8(LPC_GPIO_BASE + 0x0016)				   /*!< (@ 0x0016) Byte pin registers port 0 pin PIO0_22 */
#define B0_23				   REGISTER_8(LPC_GPIO_BASE + 0x0017)				   /*!< (@ 0x0017) Byte pin registers port 0 pin PIO0_23 */
#define B0_24				   REGISTER_8(LPC_GPIO_BASE + 0x0018)				   /*!< (@ 0x0018) Byte pin registers port 0 pin PIO0_24 */
#define B0_25				   REGISTER_8(LPC_GPIO_BASE + 0x0019)				   /*!< (@ 0x0019) Byte pin registers port 0 pin PIO0_25 */
#define B0_26				   REGISTER_8(LPC_GPIO_BASE + 0x001A)				   /*!< (@ 0x001A) Byte pin registers port 0 pin PIO0_26 */
#define B0_27				   REGISTER_8(LPC_GPIO_BASE + 0x001B)				   /*!< (@ 0x001B) Byte pin registers port 0 pin PIO0_27 */
#define B0_28				   REGISTER_8(LPC_GPIO_BASE + 0x001C)				   /*!< (@ 0x001C) Byte pin registers port 0 pin PIO0_28 */
#define B0_29				   REGISTER_8(LPC_GPIO_BASE + 0x001D)				   /*!< (@ 0x001D) Byte pin registers port 0 pin PIO0_29 */
#define B0_30				   REGISTER_8(LPC_GPIO_BASE + 0x001E)				   /*!< (@ 0x001E) Byte pin registers port 0 pin PIO0_30 */
#define B0_31				   REGISTER_8(LPC_GPIO_BASE + 0x001F)				   /*!< (@ 0x001F) Byte pin registers port 0 pin PIO0_31 */
                                                                                                                                         
#define B1_0                   REGISTER_8(LPC_GPIO_BASE + 0x0020) 				   /*!< (@ 0x0020) Byte pin registers port 1 pin PIO1_0 */
#define B1_1				   REGISTER_8(LPC_GPIO_BASE + 0x0021)				   /*!< (@ 0x0021) Byte pin registers port 1 pin PIO1_1 */
#define B1_2				   REGISTER_8(LPC_GPIO_BASE + 0x0022)				   /*!< (@ 0x0022) Byte pin registers port 1 pin PIO1_2 */
#define B1_3				   REGISTER_8(LPC_GPIO_BASE + 0x0023)				   /*!< (@ 0x0023) Byte pin registers port 1 pin PIO1_3 */
#define B1_4				   REGISTER_8(LPC_GPIO_BASE + 0x0024)				   /*!< (@ 0x0024) Byte pin registers port 1 pin PIO1_4 */
#define B1_5				   REGISTER_8(LPC_GPIO_BASE + 0x0025)				   /*!< (@ 0x0025) Byte pin registers port 1 pin PIO1_5 */
#define B1_6				   REGISTER_8(LPC_GPIO_BASE + 0x0026)				   /*!< (@ 0x0026) Byte pin registers port 1 pin PIO1_6 */
#define B1_7				   REGISTER_8(LPC_GPIO_BASE + 0x0027)				   /*!< (@ 0x0027) Byte pin registers port 1 pin PIO1_7 */
#define B1_8				   REGISTER_8(LPC_GPIO_BASE + 0x0028)				   /*!< (@ 0x0028) Byte pin registers port 1 pin PIO1_8 */
#define B1_9				   REGISTER_8(LPC_GPIO_BASE + 0x0029)				   /*!< (@ 0x0029) Byte pin registers port 1 pin PIO1_9 */
#define B1_10				   REGISTER_8(LPC_GPIO_BASE + 0x002A)				   /*!< (@ 0x002A) Byte pin registers port 1 pin PIO1_10 */
#define B1_11				   REGISTER_8(LPC_GPIO_BASE + 0x002B)				   /*!< (@ 0x002B) Byte pin registers port 1 pin PIO1_11 */
#define B1_12				   REGISTER_8(LPC_GPIO_BASE + 0x002C)				   /*!< (@ 0x002C) Byte pin registers port 1 pin PIO1_12 */
#define B1_13				   REGISTER_8(LPC_GPIO_BASE + 0x002D)				   /*!< (@ 0x002D) Byte pin registers port 1 pin PIO1_13 */
#define B1_14				   REGISTER_8(LPC_GPIO_BASE + 0x002E)				   /*!< (@ 0x002E) Byte pin registers port 1 pin PIO1_14 */
#define B1_15				   REGISTER_8(LPC_GPIO_BASE + 0x002F)				   /*!< (@ 0x002F) Byte pin registers port 1 pin PIO1_15 */
#define B1_16				   REGISTER_8(LPC_GPIO_BASE + 0x0030)				   /*!< (@ 0x0030) Byte pin registers port 1 pin PIO1_16 */
#define B1_17				   REGISTER_8(LPC_GPIO_BASE + 0x0031)				   /*!< (@ 0x0031) Byte pin registers port 1 pin PIO1_17 */
#define B1_18				   REGISTER_8(LPC_GPIO_BASE + 0x0032)				   /*!< (@ 0x0032) Byte pin registers port 1 pin PIO1_18 */
#define B1_19				   REGISTER_8(LPC_GPIO_BASE + 0x0033)				   /*!< (@ 0x0033) Byte pin registers port 1 pin PIO1_19 */
#define B1_20				   REGISTER_8(LPC_GPIO_BASE + 0x0034)				   /*!< (@ 0x0034) Byte pin registers port 1 pin PIO1_20 */
#define B1_21				   REGISTER_8(LPC_GPIO_BASE + 0x0035)				   /*!< (@ 0x0035) Byte pin registers port 1 pin PIO1_21 */
#define B1_22				   REGISTER_8(LPC_GPIO_BASE + 0x0036)				   /*!< (@ 0x0036) Byte pin registers port 1 pin PIO1_22 */
#define B1_23				   REGISTER_8(LPC_GPIO_BASE + 0x0037)				   /*!< (@ 0x0037) Byte pin registers port 1 pin PIO1_23 */
#define B1_24				   REGISTER_8(LPC_GPIO_BASE + 0x0038)				   /*!< (@ 0x0038) Byte pin registers port 1 pin PIO1_24 */
#define B1_25				   REGISTER_8(LPC_GPIO_BASE + 0x0039)				   /*!< (@ 0x0039) Byte pin registers port 1 pin PIO1_25 */
#define B1_26				   REGISTER_8(LPC_GPIO_BASE + 0x003A)				   /*!< (@ 0x003A) Byte pin registers port 1 pin PIO1_26 */
#define B1_27				   REGISTER_8(LPC_GPIO_BASE + 0x003B)				   /*!< (@ 0x003B) Byte pin registers port 1 pin PIO1_27 */
#define B1_28				   REGISTER_8(LPC_GPIO_BASE + 0x003C)				   /*!< (@ 0x003C) Byte pin registers port 1 pin PIO1_28 */
#define B1_29				   REGISTER_8(LPC_GPIO_BASE + 0x003D)				   /*!< (@ 0x003D) Byte pin registers port 1 pin PIO1_29 */
#define B1_30				   REGISTER_8(LPC_GPIO_BASE + 0x003E)				   /*!< (@ 0x003E) Byte pin registers port 1 pin PIO1_30 */
#define B1_31				   REGISTER_8(LPC_GPIO_BASE + 0x003F)				   /*!< (@ 0x003F) Byte pin registers port 1 pin PIO1_31 */
                                                                               
#define W0_0                   REGISTER_32(LPC_GPIO_BASE + 0x1000) 				   /*!< (@ 0x1000) Byte pin registers port 0 pin PIO0_0 */
#define W0_1				   REGISTER_32(LPC_GPIO_BASE + 0x1004)				   /*!< (@ 0x1004) Byte pin registers port 0 pin PIO0_1 */
#define W0_2				   REGISTER_32(LPC_GPIO_BASE + 0x1008)				   /*!< (@ 0x1008) Byte pin registers port 0 pin PIO0_2 */
#define W0_3				   REGISTER_32(LPC_GPIO_BASE + 0x100C)				   /*!< (@ 0x100C) Byte pin registers port 0 pin PIO0_3 */
#define W0_4				   REGISTER_32(LPC_GPIO_BASE + 0x1010)				   /*!< (@ 0x1010) Byte pin registers port 0 pin PIO0_4 */
#define W0_5				   REGISTER_32(LPC_GPIO_BASE + 0x1014)				   /*!< (@ 0x1014) Byte pin registers port 0 pin PIO0_5 */
#define W0_6				   REGISTER_32(LPC_GPIO_BASE + 0x1018)				   /*!< (@ 0x1018) Byte pin registers port 0 pin PIO0_6 */
#define W0_7				   REGISTER_32(LPC_GPIO_BASE + 0x101C)				   /*!< (@ 0x101C) Byte pin registers port 0 pin PIO0_7 */
#define W0_8				   REGISTER_32(LPC_GPIO_BASE + 0x1020)				   /*!< (@ 0x1020) Byte pin registers port 0 pin PIO0_8 */
#define W0_9				   REGISTER_32(LPC_GPIO_BASE + 0x1024)				   /*!< (@ 0x1024) Byte pin registers port 0 pin PIO0_9 */
#define W0_10				   REGISTER_32(LPC_GPIO_BASE + 0x1028)				   /*!< (@ 0x1028) Byte pin registers port 0 pin PIO0_10 */
#define W0_11				   REGISTER_32(LPC_GPIO_BASE + 0x102C)				   /*!< (@ 0x102C) Byte pin registers port 0 pin PIO0_11 */
#define W0_12				   REGISTER_32(LPC_GPIO_BASE + 0x1030)				   /*!< (@ 0x1030) Byte pin registers port 0 pin PIO0_12 */
#define W0_13				   REGISTER_32(LPC_GPIO_BASE + 0x1034)				   /*!< (@ 0x1034) Byte pin registers port 0 pin PIO0_13 */
#define W0_14				   REGISTER_32(LPC_GPIO_BASE + 0x1038)				   /*!< (@ 0x1038) Byte pin registers port 0 pin PIO0_14 */
#define W0_15				   REGISTER_32(LPC_GPIO_BASE + 0x103C)				   /*!< (@ 0x103C) Byte pin registers port 0 pin PIO0_15 */
#define W0_16				   REGISTER_32(LPC_GPIO_BASE + 0x1040)				   /*!< (@ 0x1040) Byte pin registers port 0 pin PIO0_16 */
#define W0_17				   REGISTER_32(LPC_GPIO_BASE + 0x1044)				   /*!< (@ 0x1044) Byte pin registers port 0 pin PIO0_17 */
#define W0_18				   REGISTER_32(LPC_GPIO_BASE + 0x1048)				   /*!< (@ 0x1048) Byte pin registers port 0 pin PIO0_18 */
#define W0_19				   REGISTER_32(LPC_GPIO_BASE + 0x104C)				   /*!< (@ 0x104C) Byte pin registers port 0 pin PIO0_19 */
#define W0_20				   REGISTER_32(LPC_GPIO_BASE + 0x1050)				   /*!< (@ 0x1050) Byte pin registers port 0 pin PIO0_20 */
#define W0_21				   REGISTER_32(LPC_GPIO_BASE + 0x1054)				   /*!< (@ 0x1054) Byte pin registers port 0 pin PIO0_21 */
#define W0_22				   REGISTER_32(LPC_GPIO_BASE + 0x1058)				   /*!< (@ 0x1058) Byte pin registers port 0 pin PIO0_22 */
#define W0_23				   REGISTER_32(LPC_GPIO_BASE + 0x105C)				   /*!< (@ 0x105C) Byte pin registers port 0 pin PIO0_23 */
#define W0_24				   REGISTER_32(LPC_GPIO_BASE + 0x1060)				   /*!< (@ 0x1060) Byte pin registers port 0 pin PIO0_24 */
#define W0_25				   REGISTER_32(LPC_GPIO_BASE + 0x1064)				   /*!< (@ 0x1064) Byte pin registers port 0 pin PIO0_25 */
#define W0_26				   REGISTER_32(LPC_GPIO_BASE + 0x1068)				   /*!< (@ 0x1068) Byte pin registers port 0 pin PIO0_26 */
#define W0_27				   REGISTER_32(LPC_GPIO_BASE + 0x106C)				   /*!< (@ 0x106C) Byte pin registers port 0 pin PIO0_27 */
#define W0_28				   REGISTER_32(LPC_GPIO_BASE + 0x1070)				   /*!< (@ 0x1070) Byte pin registers port 0 pin PIO0_28 */
#define W0_29				   REGISTER_32(LPC_GPIO_BASE + 0x1074)				   /*!< (@ 0x1074) Byte pin registers port 0 pin PIO0_29 */
#define W0_30				   REGISTER_32(LPC_GPIO_BASE + 0x1078)				   /*!< (@ 0x1078) Byte pin registers port 0 pin PIO0_30 */
#define W0_31				   REGISTER_32(LPC_GPIO_BASE + 0x107C)				   /*!< (@ 0x107C) Byte pin registers port 0 pin PIO0_31 */

#define W1_0                   REGISTER_32(LPC_GPIO_BASE + 0x1080) 				   /*!< (@ 0x1080) Byte pin registers port 1 pin PIO0_0 */
#define W1_1				   REGISTER_32(LPC_GPIO_BASE + 0x1084)				   /*!< (@ 0x1084) Byte pin registers port 1 pin PIO0_1 */
#define W1_2				   REGISTER_32(LPC_GPIO_BASE + 0x1088)				   /*!< (@ 0x1088) Byte pin registers port 1 pin PIO0_2 */
#define W1_3				   REGISTER_32(LPC_GPIO_BASE + 0x108C)				   /*!< (@ 0x108C) Byte pin registers port 1 pin PIO0_3 */
#define W1_4				   REGISTER_32(LPC_GPIO_BASE + 0x1090)				   /*!< (@ 0x1090) Byte pin registers port 1 pin PIO0_4 */
#define W1_5				   REGISTER_32(LPC_GPIO_BASE + 0x1094)				   /*!< (@ 0x1094) Byte pin registers port 1 pin PIO0_5 */
#define W1_6				   REGISTER_32(LPC_GPIO_BASE + 0x1098)				   /*!< (@ 0x1098) Byte pin registers port 1 pin PIO0_6 */
#define W1_7				   REGISTER_32(LPC_GPIO_BASE + 0x109C)				   /*!< (@ 0x109C) Byte pin registers port 1 pin PIO0_7 */
#define W1_8				   REGISTER_32(LPC_GPIO_BASE + 0x10A0)				   /*!< (@ 0x10A0) Byte pin registers port 1 pin PIO0_8 */
#define W1_9				   REGISTER_32(LPC_GPIO_BASE + 0x10A4)				   /*!< (@ 0x10A4) Byte pin registers port 1 pin PIO0_9 */
#define W1_10				   REGISTER_32(LPC_GPIO_BASE + 0x10A8)				   /*!< (@ 0x10A8) Byte pin registers port 1 pin PIO0_10 */
#define W1_11				   REGISTER_32(LPC_GPIO_BASE + 0x10AC)				   /*!< (@ 0x10AC) Byte pin registers port 1 pin PIO0_11 */
#define W1_12				   REGISTER_32(LPC_GPIO_BASE + 0x10B0)				   /*!< (@ 0x10B0) Byte pin registers port 1 pin PIO0_12 */
#define W1_13				   REGISTER_32(LPC_GPIO_BASE + 0x10B4)				   /*!< (@ 0x10B4) Byte pin registers port 1 pin PIO0_13 */
#define W1_14				   REGISTER_32(LPC_GPIO_BASE + 0x10B8)				   /*!< (@ 0x10B8) Byte pin registers port 1 pin PIO0_14 */
#define W1_15				   REGISTER_32(LPC_GPIO_BASE + 0x10BC)				   /*!< (@ 0x10BC) Byte pin registers port 1 pin PIO0_15 */
#define W1_16				   REGISTER_32(LPC_GPIO_BASE + 0x10C0)				   /*!< (@ 0x10C0) Byte pin registers port 1 pin PIO0_16 */
#define W1_17				   REGISTER_32(LPC_GPIO_BASE + 0x10C4)				   /*!< (@ 0x10C4) Byte pin registers port 1 pin PIO0_17 */
#define W1_18				   REGISTER_32(LPC_GPIO_BASE + 0x10C8)				   /*!< (@ 0x10C8) Byte pin registers port 1 pin PIO0_18 */
#define W1_19				   REGISTER_32(LPC_GPIO_BASE + 0x10CC)				   /*!< (@ 0x10CC) Byte pin registers port 1 pin PIO0_19 */
#define W1_20				   REGISTER_32(LPC_GPIO_BASE + 0x10D0)				   /*!< (@ 0x10D0) Byte pin registers port 1 pin PIO0_20 */
#define W1_21				   REGISTER_32(LPC_GPIO_BASE + 0x10D4)				   /*!< (@ 0x10D4) Byte pin registers port 1 pin PIO0_21 */
#define W1_22				   REGISTER_32(LPC_GPIO_BASE + 0x10D8)				   /*!< (@ 0x10D8) Byte pin registers port 1 pin PIO0_22 */
#define W1_23				   REGISTER_32(LPC_GPIO_BASE + 0x10DC)				   /*!< (@ 0x10DC) Byte pin registers port 1 pin PIO0_23 */
#define W1_24				   REGISTER_32(LPC_GPIO_BASE + 0x10E0)				   /*!< (@ 0x10E0) Byte pin registers port 1 pin PIO0_24 */
#define W1_25				   REGISTER_32(LPC_GPIO_BASE + 0x10E4)				   /*!< (@ 0x10E4) Byte pin registers port 1 pin PIO0_25 */
#define W1_26				   REGISTER_32(LPC_GPIO_BASE + 0x10E8)				   /*!< (@ 0x10E8) Byte pin registers port 1 pin PIO0_26 */
#define W1_27				   REGISTER_32(LPC_GPIO_BASE + 0x10EC)				   /*!< (@ 0x10EC) Byte pin registers port 1 pin PIO0_27 */
#define W1_28				   REGISTER_32(LPC_GPIO_BASE + 0x10F0)				   /*!< (@ 0x10F0) Byte pin registers port 1 pin PIO0_28 */
#define W1_29				   REGISTER_32(LPC_GPIO_BASE + 0x10F4)				   /*!< (@ 0x10F4) Byte pin registers port 1 pin PIO0_29 */
#define W1_30				   REGISTER_32(LPC_GPIO_BASE + 0x10F8)				   /*!< (@ 0x10F8) Byte pin registers port 1 pin PIO0_30 */
#define W1_31				   REGISTER_32(LPC_GPIO_BASE + 0x10FC)				   /*!< (@ 0x10FC) Byte pin registers port 1 pin PIO0_31 */
									                                                  			                                           
#define DIR0                   REGISTER_32(LPC_GPIO_BASE + 0x2000)  			   /*!< (@ 0x2000) Direction register port 0 */
#define DIR1                   REGISTER_32(LPC_GPIO_BASE + 0x2004)  			   /*!< (@ 0x2004) Direction register port 1 */
      	                                                   
#define MASK0                  REGISTER_32(LPC_GPIO_BASE + 0x2080)  			   /*!< (@ 0x2080) Mask register port 0 */
#define MASK1                  REGISTER_32(LPC_GPIO_BASE + 0x2084)  			   /*!< (@ 0x2084) Mask register port 1 */ 
      	                                                   
#define PIN0                   REGISTER_32(LPC_GPIO_BASE + 0x2100)  			   /*!< (@ 0x2100) Port pin register port 0 */
#define PIN1                   REGISTER_32(LPC_GPIO_BASE + 0x2104)  			   /*!< (@ 0x2104) Port pin register port 1 */
        	                                                   
#define MPIN0                  REGISTER_32(LPC_GPIO_BASE + 0x2180)  			   /*!< (@ 0x2180) Masked port register port 0*/
#define MPIN1                  REGISTER_32(LPC_GPIO_BASE + 0x2184)  			   /*!< (@ 0x2184) Masked port register port 1*/
        	                                                   
#define SET0                   REGISTER_32(LPC_GPIO_BASE + 0x2200)  			   /*!< (@ 0x2200) Set register port 0 */
#define SET1                   REGISTER_32(LPC_GPIO_BASE + 0x2204)  			   /*!< (@ 0x2204) Set register port 1 */
    	                                                   
#define CLR0                   REGISTER_32(LPC_GPIO_BASE + 0x2280)  			   /*!< (@ 0x2280) Clear port register port 0 */
#define CLR1                   REGISTER_32(LPC_GPIO_BASE + 0x2284)  			   /*!< (@ 0x2284) Clear port register port 1 */
        	                                                   
#define NOT0                   REGISTER_32(LPC_GPIO_BASE + 0x2300)  			   /*!< (@ 0x2300) Toggle port register port 0 */
#define NOT1                   REGISTER_32(LPC_GPIO_BASE + 0x2304)  			   /*!< (@ 0x2304) Toggle port register port 1 */

/*------------- General Purpose Input/Output (GPIO_PIN_INT) --------------------------*/
                         
#define ISEL                   REGISTER_32(LPC_GPIO_PIN_INT_BASE + 0x000)   	   /*!< (@ 0x000) Pin Interrupt Mode register */
#define IENR                   REGISTER_32(LPC_GPIO_PIN_INT_BASE + 0x004)   	   /*!< (@ 0x004) Pin Interrupt Enable (Rising) register */
#define SIENR                  REGISTER_32(LPC_GPIO_PIN_INT_BASE + 0x008)   	   /*!< (@ 0x008) Set Pin Interrupt Enable (Rising) register */
#define CIENR                  REGISTER_32(LPC_GPIO_PIN_INT_BASE + 0x00C)   	   /*!< (@ 0x00C) Clear Pin Interrupt Enable (Rising) register */
#define IENF                   REGISTER_32(LPC_GPIO_PIN_INT_BASE + 0x010)   	   /*!< (@ 0x010) Pin Interrupt Enable Falling Edge / Active Level register */
#define SIENF                  REGISTER_32(LPC_GPIO_PIN_INT_BASE + 0x014)   	   /*!< (@ 0x014) Set Pin Interrupt Enable Falling Edge / Active Level register */
#define CIENF                  REGISTER_32(LPC_GPIO_PIN_INT_BASE + 0x018)   	   /*!< (@ 0x018) Clear Pin Interrupt Enable Falling Edge / Active Level address */
#define RISE                   REGISTER_32(LPC_GPIO_PIN_INT_BASE + 0x01C)   	   /*!< (@ 0x01C) Pin Interrupt Rising Edge register */
#define FALL                   REGISTER_32(LPC_GPIO_PIN_INT_BASE + 0x020)   	   /*!< (@ 0x020) Pin Interrupt Falling Edge register */
#define IST                    REGISTER_32(LPC_GPIO_PIN_INT_BASE + 0x024)   	   /*!< (@ 0x024) Pin Interrupt Status register */

/*------------- General Purpose Input/Output (GPIO_GROUP_INT0) --------------------------*/

#define INT0_CTRL              REGISTER_32(LPC_GPIO_GROUP_INT0_BASE + 0x000)	   /*!< (@ 0x000) GPIO grouped interrupt control register */
     	                                                   
#define INT0_PORT_POL0         REGISTER_32(LPC_GPIO_GROUP_INT0_BASE + 0x020)	   /*!< (@ 0x020) GPIO grouped interrupt port 0 polarity register */
#define INT0_PORT_POL1         REGISTER_32(LPC_GPIO_GROUP_INT0_BASE + 0x024)	   /*!< (@ 0x024) GPIO grouped interrupt port 1 polarity register */
     	                                                   
#define INT0_PORT_ENA0         REGISTER_32(LPC_GPIO_GROUP_INT0_BASE + 0x040)	   /*!< (@ 0x040) GPIO grouped interrupt port 0 enable register */
#define INT0_PORT_ENA1         REGISTER_32(LPC_GPIO_GROUP_INT0_BASE + 0x044)	   /*!< (@ 0x044) GPIO grouped interrupt port 1 enable register */

/*------------- General Purpose Input/Output (GPIO_GROUP_INT1) --------------------------*/
                
#define INT1_CTRL              REGISTER_32(LPC_GPIO_GROUP_INT1_BASE + 0x000)	   /*!< (@ 0x000) GPIO grouped interrupt control register */
                                  	                   
#define INT1_PORT_POL0         REGISTER_32(LPC_GPIO_GROUP_INT1_BASE + 0x020)	   /*!< (@ 0x020) GPIO grouped interrupt port 0 polarity register */
#define INT1_PORT_POL1         REGISTER_32(LPC_GPIO_GROUP_INT0_BASE + 0x024)	   /*!< (@ 0x024) GPIO grouped interrupt port 1 polarity register */
                                    	                   
#define INT1_PORT_ENA0         REGISTER_32(LPC_GPIO_GROUP_INT1_BASE + 0x040)	   /*!< (@ 0x040) GPIO grouped interrupt port 0 enable register */
#define INT1_PORT_ENA1         REGISTER_32(LPC_GPIO_GROUP_INT0_BASE + 0x044)	   /*!< (@ 0x044) GPIO grouped interrupt port 1 enable register */

/*------------- Timer TMR16B0(TMR) --------------------------------------------------*/

#define CT16B0_IR              REGISTER_32(LPC_CT16B0_BASE + 0x000)    			   /*!< (@ 0x000) Interrupt Register */
#define CT16B0_TCR             REGISTER_32(LPC_CT16B0_BASE + 0x004)    			   /*!< (@ 0x004) Timer Control Register */
#define CT16B0_TC              REGISTER_32(LPC_CT16B0_BASE + 0x008)    			   /*!< (@ 0x008) Timer Counter */
#define CT16B0_PR              REGISTER_32(LPC_CT16B0_BASE + 0x00C)    			   /*!< (@ 0x010) Prescale Register  */
#define CT16B0_PC              REGISTER_32(LPC_CT16B0_BASE + 0x010)    			   /*!< (@ 0x014) Prescale Counter */
#define CT16B0_MCR             REGISTER_32(LPC_CT16B0_BASE + 0x014)    			   /*!< (@ 0x014) Match Control Register */
				                                                                   
#define CT16B0_MR0             REGISTER_32(LPC_CT16B0_BASE + 0x018)    			   /*!< (@ 0x018) Match Register. MR0 */
#define CT16B0_MR1             REGISTER_32(LPC_CT16B0_BASE + 0x01C)    			   /*!< (@ 0x01C) Match Register. MR1 */
#define CT16B0_MR2             REGISTER_32(LPC_CT16B0_BASE + 0x020)    			   /*!< (@ 0x020) Match Register. MR2 */
#define CT16B0_MR3             REGISTER_32(LPC_CT16B0_BASE + 0x024)    			   /*!< (@ 0x024) Match Register. MR3 */
		                                                                           
#define CT16B0_CCR             REGISTER_32(LPC_CT16B0_BASE + 0x028)    			   /*!< (@ 0x028) Capture Control Register */
				                                                                   
#define CT16B0_CR0             REGISTER_32(LPC_CT16B0_BASE + 0x02C)    			   /*!< (@ 0x02C) Capture Register. CR 0 */
#define CT16B0_RESERVED1       REGISTER_32(LPC_CT16B0_BASE + 0x030)    			   /*!< (@ 0x030) Reserved */
#define CT16B0_CR1             REGISTER_32(LPC_CT16B0_BASE + 0x034)    			   /*!< (@ 0x034) Capture Register. CR 1 */
#define CT16B0_RESERVED2       REGISTER_32(LPC_CT16B0_BASE + 0x038)    			   /*!< (@ 0x038) Reserved */
		                                                                           
#define CT16B0_EMR             REGISTER_32(LPC_CT16B0_BASE + 0x03C)    			   /*!< (@ 0x03C) External Match Register */
  		                                               
#define CT16B0_CTCR            REGISTER_32(LPC_CT16B0_BASE + 0x070)    			   /*!< (@ 0x070) Count Control Register */
#define CT16B0_PWMC            REGISTER_32(LPC_CT16B0_BASE + 0x074)    			   /*!< (@ 0x074) PWM Control Register */

/*------------- Timer TMR16B1(TMR) --------------------------------------------------*/

#define CT16B1_IR              REGISTER_32(LPC_CT16B1_BASE + 0x000)    			   /*!< (@ 0x000) Interrupt Register */
#define CT16B1_TCR             REGISTER_32(LPC_CT16B1_BASE + 0x004)    			   /*!< (@ 0x004) Timer Control Register */
#define CT16B1_TC              REGISTER_32(LPC_CT16B1_BASE + 0x008)    			   /*!< (@ 0x008) Timer Counter */
#define CT16B1_PR              REGISTER_32(LPC_CT16B1_BASE + 0x00C)    			   /*!< (@ 0x00C) Prescale Register */
#define CT16B1_PC              REGISTER_32(LPC_CT16B1_BASE + 0x010)    			   /*!< (@ 0x010) Prescale Counter */
#define CT16B1_MCR             REGISTER_32(LPC_CT16B1_BASE + 0x014)    			   /*!< (@ 0x014) Match Control Register */
				                                                                   
#define CT16B1_MR0             REGISTER_32(LPC_CT16B1_BASE + 0x018)    			   /*!< (@ 0x018) Match Register. MR0 */
#define CT16B1_MR1             REGISTER_32(LPC_CT16B1_BASE + 0x01C)    			   /*!< (@ 0x01C) Match Register. MR1 */
#define CT16B1_MR2             REGISTER_32(LPC_CT16B1_BASE + 0x020)    			   /*!< (@ 0x020) Match Register. MR2 */
#define CT16B1_MR3             REGISTER_32(LPC_CT16B1_BASE + 0x024)    			   /*!< (@ 0x024) Match Register. MR3 */
				                                                                   
#define CT16B1_CCR             REGISTER_32(LPC_CT16B1_BASE + 0x028)    			   /*!< (@ 0x028) Capture Control Register */
			                                                                       
#define CT16B1_CR0             REGISTER_32(LPC_CT16B1_BASE + 0x02C)    			   /*!< (@ 0x02C) Capture Register. CR 0 */
#define CT16B1_CR1             REGISTER_32(LPC_CT16B1_BASE + 0x030)    			   /*!< (@ 0x030) Capture Register. CR 1 */
#define CT16B1_RESERVED1       REGISTER_32(LPC_CT16B1_BASE + 0x034)    			   /*!< (@ 0x034) Capture Register. CR 2 */
#define CT16B1_RESERVED2       REGISTER_32(LPC_CT16B1_BASE + 0x038)    			   /*!< (@ 0x038) Capture Register. CR 3 */
				                                                                   
#define CT16B1_EMR             REGISTER_32(LPC_CT16B1_BASE + 0x03C)    			   /*!< (@ 0x03C) External Match Register */
	                 	                               
#define CT16B1_CTCR            REGISTER_32(LPC_CT16B1_BASE + 0x070)    			   /*!< (@ 0x070) Count Control Register */
#define CT16B1_PWMC            REGISTER_32(LPC_CT16B1_BASE + 0x074)    			   /*!< (@ 0x074) PWM Control Register */

/*------------- Timer TMR32B0(TMR) --------------------------------------------------*/

#define CT32B0_IR              REGISTER_32(LPC_CT32B0_BASE + 0x000)    			   /*!< (@ 0x000) Interrupt Register */
#define CT32B0_TCR             REGISTER_32(LPC_CT32B0_BASE + 0x004)    			   /*!< (@ 0x004) Timer Control Register */
#define CT32B0_TC              REGISTER_32(LPC_CT32B0_BASE + 0x008)    			   /*!< (@ 0x008) Timer Counter */
#define CT32B0_PR              REGISTER_32(LPC_CT32B0_BASE + 0x00C)    			   /*!< (@ 0x010) Prescale Register  */
#define CT32B0_PC              REGISTER_32(LPC_CT32B0_BASE + 0x010)    			   /*!< (@ 0x014) Prescale Counter */
#define CT32B0_MCR             REGISTER_32(LPC_CT32B0_BASE + 0x014)    			   /*!< (@ 0x014) Match Control Register */
				                                                                   
#define CT32B0_MR0             REGISTER_32(LPC_CT32B0_BASE + 0x018)    			   /*!< (@ 0x018) Match Register. MR0 */
#define CT32B0_MR1             REGISTER_32(LPC_CT32B0_BASE + 0x01C)    			   /*!< (@ 0x01C) Match Register. MR1 */
#define CT32B0_MR2             REGISTER_32(LPC_CT32B0_BASE + 0x020)    			   /*!< (@ 0x020) Match Register. MR2 */
#define CT32B0_MR3             REGISTER_32(LPC_CT32B0_BASE + 0x024)    			   /*!< (@ 0x024) Match Register. MR3 */
			                                                                       
#define CT32B0_CCR             REGISTER_32(LPC_CT32B0_BASE + 0x028)    			   /*!< (@ 0x028) Capture Control Register */
				                                                                   
#define CT32B0_CR0             REGISTER_32(LPC_CT32B0_BASE + 0x02C)    			   /*!< (@ 0x02C) Capture Register. CR 0 */
#define CT32B0_RESERVED1       REGISTER_32(LPC_CT32B0_BASE + 0x030)    			   /*!< (@ 0x030) Reserved */
#define CT32B0_CR1             REGISTER_32(LPC_CT32B0_BASE + 0x034)    			   /*!< (@ 0x034) Capture Register. CR 1 */
#define CT32B0_RESERVED2       REGISTER_32(LPC_CT32B0_BASE + 0x038)    			   /*!< (@ 0x038) Reserved */
			                                                                       
#define CT32B0_EMR             REGISTER_32(LPC_CT32B0_BASE + 0x03C)    			   /*!< (@ 0x03C) External Match Register */
 	                	                               
#define CT32B0_CTCR            REGISTER_32(LPC_CT32B0_BASE + 0x070)    			   /*!< (@ 0x070) Count Control Register */
#define CT32B0_PWMC            REGISTER_32(LPC_CT32B0_BASE + 0x074)    			   /*!< (@ 0x074) PWM Control Register */

/*------------- Timer TMR32B1(TMR) --------------------------------------------------*/

#define CT32B1_IR              REGISTER_32(LPC_CT32B1_BASE + 0x000)    			   /*!< (@ 0x000) Interrupt Register */
#define CT32B1_TCR             REGISTER_32(LPC_CT32B1_BASE + 0x004)    			   /*!< (@ 0x004) Timer Control Register */
#define CT32B1_TC              REGISTER_32(LPC_CT32B1_BASE + 0x008)    			   /*!< (@ 0x008) Timer Counter */
#define CT32B1_PR              REGISTER_32(LPC_CT32B1_BASE + 0x00C)    			   /*!< (@ 0x00C) Prescale Register */
#define CT32B1_PC              REGISTER_32(LPC_CT32B1_BASE + 0x010)    			   /*!< (@ 0x010) Prescale Counter */
#define CT32B1_MCR             REGISTER_32(LPC_CT32B1_BASE + 0x014)    			   /*!< (@ 0x014) Match Control Register */
				                                                                   
#define CT32B1_MR0             REGISTER_32(LPC_CT32B1_BASE + 0x018)    			   /*!< (@ 0x018) Match Register. MR0 */
#define CT32B1_MR1             REGISTER_32(LPC_CT32B1_BASE + 0x01C)    			   /*!< (@ 0x01C) Match Register. MR1 */
#define CT32B1_MR2             REGISTER_32(LPC_CT32B1_BASE + 0x020)    			   /*!< (@ 0x020) Match Register. MR2 */
#define CT32B1_MR3             REGISTER_32(LPC_CT32B1_BASE + 0x024)    			   /*!< (@ 0x024) Match Register. MR3 */
			                                                                       
#define CT32B1_CCR             REGISTER_32(LPC_CT32B1_BASE + 0x028)    			   /*!< (@ 0x028) Capture Control Register */
			                                                                       
#define CT32B1_CR0             REGISTER_32(LPC_CT32B1_BASE + 0x02C)    			   /*!< (@ 0x02C) Capture Register. CR 0 */
#define CT32B1_CR1             REGISTER_32(LPC_CT32B1_BASE + 0x030)    			   /*!< (@ 0x030) Capture Register. CR 1 */
#define CT32B1_RESERVED1       REGISTER_32(LPC_CT32B1_BASE + 0x034)    			   /*!< (@ 0x034) Capture Register. CR 2 */
#define CT32B1_RESERVED2       REGISTER_32(LPC_CT32B1_BASE + 0x038)    			   /*!< (@ 0x038) Capture Register. CR 3 */
			                                                                       
#define CT32B1_EMR             REGISTER_32(LPC_CT32B1_BASE + 0x03C)    			   /*!< (@ 0x03C) External Match Register */
   	                 	                               
#define CT32B1_CTCR            REGISTER_32(LPC_CT32B1_BASE + 0x070)    			   /*!< (@ 0x070) Count Control Register */
#define CT32B1_PWMC            REGISTER_32(LPC_CT32B1_BASE + 0x074)    			   /*!< (@ 0x074) PWM Control Register */

/*------------- Universal Asynchronous Receiver Transmitter (UART) -----------*/

#define UDLL                   REGISTER_32(LPC_USART_BASE + 0x000) 	 	 		   /*!< (@ 0x000) Divisor Latch LSB. Least significant byte of the baud rate divisor value. The full divisor is used to generate a baud rate from the fractional rate divider. (DLAB=1) */
#define UTHR                   REGISTER_32(LPC_USART_BASE + 0x000)  	 		   /*!< (@ 0x000) Transmit Holding Register. The next character to be transmitted is written here. (DLAB=0) */
#define URBR                   REGISTER_32(LPC_USART_BASE + 0x000)  	 		   /*!< (@ 0x000) Receiver Buffer Register. Contains the next received character to be read. (DLAB=0) */
		                                                                          
#define UIER                   REGISTER_32(LPC_USART_BASE + 0x004)  	 		   /*!< (@ 0x004) Interrupt Enable Register. Contains individual interrupt enable bits for the 7 potential USART interrupts. (DLAB=0) */
#define UDLM                   REGISTER_32(LPC_USART_BASE + 0x004)  	 		   /*!< (@ 0x004) Divisor Latch MSB. Most significant byte of the baud rate divisor value. The full divisor is used to generate a baud rate from the fractional rate divider. (DLAB=1) */
		                                                                          
#define UFCR                   REGISTER_32(LPC_USART_BASE + 0x008)  	 		   /*!< (@ 0x008) FIFO Control Register. Controls USART FIFO usage and modes. */
#define UIIR                   REGISTER_32(LPC_USART_BASE + 0x008)  	 		   /*!< (@ 0x008) Interrupt ID Register. Identifies which interrupt(s) are pending. */
	                                                                              
#define ULCR                   REGISTER_32(LPC_USART_BASE + 0x00C)   			   /*!< (@ 0x00C) Line Control Register. Contains controls for frame formatting and break generation. */
#define UMCR                   REGISTER_32(LPC_USART_BASE + 0x010)   			   /*!< (@ 0x010) Modem Control Register. */
#define ULSR                   REGISTER_32(LPC_USART_BASE + 0x014)   			   /*!< (@ 0x014) Line Status Register. Contains flags for transmit and receive status, including line errors. */
#define UMSR                   REGISTER_32(LPC_USART_BASE + 0x018)   			   /*!< (@ 0x018) Modem Status Register. */
#define USCR                   REGISTER_32(LPC_USART_BASE + 0x01C)   			   /*!< (@ 0x01C) Scratch Pad Register. Eight-bit temporary storage for software. */
#define UACR                   REGISTER_32(LPC_USART_BASE + 0x020)   			   /*!< (@ 0x020) Auto-baud Control Register. Contains controls for the auto-baud feature. */
#define UICR                   REGISTER_32(LPC_USART_BASE + 0x024)   			   /*!< (@ 0x024) IrDA Control Register. Enables and configures the IrDA (remote control) mode. */
#define UFDR                   REGISTER_32(LPC_USART_BASE + 0x028)   			   /*!< (@ 0x028) Fractional Divider Register. Generates a clock input for the baud rate divider. */
#define UOSR                   REGISTER_32(LPC_USART_BASE + 0x02C)   			   /*!< (@ 0x02C) Oversampling Register. Controls the degree of oversampling during each bit time. */
#define UTER                   REGISTER_32(LPC_USART_BASE + 0x030)   			   /*!< (@ 0x030) Transmit Enable Register. Turns off USART transmitter for use with software flow control. */
       		                                               
#define UHDEN                  REGISTER_32(LPC_USART_BASE + 0x040)   			   /*!< (@ 0x040) Half duplex enable register. */
         		                                              
#define USCICTRL               REGISTER_32(LPC_USART_BASE + 0x048)   			   /*!< (@ 0x048) Smart Card Interface Control register. Enables and configures the Smart Card Interface feature. */
#define URS485CTRL             REGISTER_32(LPC_USART_BASE + 0x04C)   			   /*!< (@ 0x04C) RS-485/EIA-485 Control. Contains controls to configure various aspects of RS-485/EIA-485 modes. */
#define URS485ADRMATCH         REGISTER_32(LPC_USART_BASE + 0x050)   			   /*!< (@ 0x050) RS-485/EIA-485 address match. Contains the address match value for RS-485/EIA-485 mode. */
#define URS485DLY              REGISTER_32(LPC_USART_BASE + 0x054)   			   /*!< (@ 0x054) RS-485/EIA-485 direction control delay. */
#define USYNCCTRL              REGISTER_32(LPC_USART_BASE + 0x058)				   /*!< (@ 0x058) Synchronous mode control register. */

/*------------- Synchronous Serial Communication (SSP0) -----------------------*/

#define SSP0_CR0               REGISTER_32(LPC_SSP0_BASE + 0x000)         		   /*!< (@ 0x000) Control Register 0. Selects the serial clock rate, bus type, and data size. */
#define SSP0_CR1               REGISTER_32(LPC_SSP0_BASE + 0x004)         		   /*!< (@ 0x004) Control Register 1. Selects master/slave and other modes. */
#define SSP0_DR                REGISTER_32(LPC_SSP0_BASE + 0x008)         		   /*!< (@ 0x008) Data Register. Writes fill the transmit FIFO, and reads empty the receive FIFO. */
#define SSP0_SR                REGISTER_32(LPC_SSP0_BASE + 0x00C)         		   /*!< (@ 0x00C) Status Register        */
#define SSP0_CPSR              REGISTER_32(LPC_SSP0_BASE + 0x010)         		   /*!< (@ 0x010) Clock Prescale Register */
#define SSP0_IMSC              REGISTER_32(LPC_SSP0_BASE + 0x014)         		   /*!< (@ 0x014) Interrupt Mask Set and Clear Register */
#define SSP0_RIS               REGISTER_32(LPC_SSP0_BASE + 0x018)         		   /*!< (@ 0x018) Raw Interrupt Status Register */
#define SSP0_MIS               REGISTER_32(LPC_SSP0_BASE + 0x01C)         		   /*!< (@ 0x01C) Masked Interrupt Status Register */
#define SSP0_ICR               REGISTER_32(LPC_SSP0_BASE + 0x020)         		   /*!< (@ 0x020) SSPICR Interrupt Clear Register */

/*------------- Synchronous Serial Communication (SSP1) -----------------------*/

#define SSP1_CR0               REGISTER_32(LPC_SSP1_BASE + 0x000)         		   /*!< (@ 0x000) Control Register 0. Selects the serial clock rate, bus type, and data size. */
#define SSP1_CR1               REGISTER_32(LPC_SSP1_BASE + 0x004)         		   /*!< (@ 0x004) Control Register 1. Selects master/slave and other modes. */
#define SSP1_DR                REGISTER_32(LPC_SSP1_BASE + 0x008)         		   /*!< (@ 0x008) Data Register. Writes fill the transmit FIFO, and reads empty the receive FIFO. */
#define SSP1_SR                REGISTER_32(LPC_SSP1_BASE + 0x00C)         		   /*!< (@ 0x00C) Status Register        */
#define SSP1_CPSR              REGISTER_32(LPC_SSP1_BASE + 0x010)         		   /*!< (@ 0x010) Clock Prescale Register */
#define SSP1_IMSC              REGISTER_32(LPC_SSP1_BASE + 0x014)         		   /*!< (@ 0x014) Interrupt Mask Set and Clear Register */
#define SSP1_RIS               REGISTER_32(LPC_SSP1_BASE + 0x018)         		   /*!< (@ 0x018) Raw Interrupt Status Register */
#define SSP1_MIS               REGISTER_32(LPC_SSP1_BASE + 0x01C)         		   /*!< (@ 0x01C) Masked Interrupt Status Register */
#define SSP1_ICR               REGISTER_32(LPC_SSP1_BASE + 0x020)         		   /*!< (@ 0x020) SSPICR Interrupt Clear Register */

/*------------- Inter-Integrated Circuit (I2C) -------------------------------*/
            
#define CONSET                 REGISTER_32(LPC_I2C_BASE + 0x000)    			   /*!< (@ 0x000) I2C Control Set Register */
#define STAT                   REGISTER_32(LPC_I2C_BASE + 0x004)    			   /*!< (@ 0x004) I2C Status Register */
#define DAT                    REGISTER_32(LPC_I2C_BASE + 0x008)    			   /*!< (@ 0x008) I2C Data Register.  */
#define ADR0                   REGISTER_32(LPC_I2C_BASE + 0x00C)    			   /*!< (@ 0x00C) I2C Slave Address Register 0 */
#define SCLH                   REGISTER_32(LPC_I2C_BASE + 0x010)    			   /*!< (@ 0x010) SCH Duty Cycle Register High Half Word */
#define SCLL                   REGISTER_32(LPC_I2C_BASE + 0x014)    			   /*!< (@ 0x014) SCL Duty Cycle Register Low Half Word */
#define CONCLR                 REGISTER_32(LPC_I2C_BASE + 0x018)    			   /*!< (@ 0x018) I2C Control Clear Register*/
#define MMCTRL                 REGISTER_32(LPC_I2C_BASE + 0x01C)    			   /*!< (@ 0x01C) Monitor mode control register*/
#define ADR1                   REGISTER_32(LPC_I2C_BASE + 0x020)    			   /*!< (@ 0x020) I2C Slave Address Register 1*/
#define ADR2                   REGISTER_32(LPC_I2C_BASE + 0x024)    			   /*!< (@ 0x024) I2C Slave Address Register 2*/
#define ADR3                   REGISTER_32(LPC_I2C_BASE + 0x028)    			   /*!< (@ 0x028) I2C Slave Address Register 3*/
#define DATA_BUFFER            REGISTER_32(LPC_I2C_BASE + 0x02C)    			   /*!< (@ 0x02C) Data buffer register */
	                                                                               
#define MASK0                  REGISTER_32(LPC_I2C_BASE + 0x030)				   /*!< (@ 0x030) I2C Slave address mask register 0 */
#define MASK1                  REGISTER_32(LPC_I2C_BASE + 0x034)				   /*!< (@ 0x030) I2C Slave address mask register 1 */
#define MASK2                  REGISTER_32(LPC_I2C_BASE + 0x038)				   /*!< (@ 0x030) I2C Slave address mask register 2 */
#define MASK3                  REGISTER_32(LPC_I2C_BASE + 0x03C)				   /*!< (@ 0x030) I2C Slave address mask register 3 */
 
/*------------- Watchdog Timer (WDT) -----------------------------------------*/

#define MOD                    REGISTER_32(LPC_WWDT_BASE + 0x000)    			   /*!< (@ 0x000) Watchdog mode register*/
#define TC                     REGISTER_32(LPC_WWDT_BASE + 0x004)    			   /*!< (@ 0x004) Watchdog timer constant register */
#define FEED                   REGISTER_32(LPC_WWDT_BASE + 0x008)    			   /*!< (@ 0x008) Watchdog feed sequence register */
#define TV                     REGISTER_32(LPC_WWDT_BASE + 0x00C)    			   /*!< (@ 0x00C) Watchdog timer value register */
#define CLKSEL                 REGISTER_32(LPC_WWDT_BASE + 0x010)    			   /*!< (@ 0x010) Watchdog clock select register. */
#define WARNINT                REGISTER_32(LPC_WWDT_BASE + 0x014)    			   /*!< (@ 0x014) Watchdog Warning Interrupt compare value. */
#define WINDOW                 REGISTER_32(LPC_WWDT_BASE + 0x018)    			   /*!< (@ 0x018) Watchdog Window compare value. */

/*------------- Analog-to-Digital Converter (ADC) ----------------------------*/

#define CR                     REGISTER_32(LPC_ADC_BASE + 0x000)    			   /*!< (@ 0x000) A/D Control Register */
#define GDR                    REGISTER_32(LPC_ADC_BASE + 0x004)    			   /*!< (@ 0x004) A/D Global Data Register */
                                    			               
#define INTEN                  REGISTER_32(LPC_ADC_BASE + 0x00C)    			   /*!< (@ 0x00C) A/D Interrupt Enable Register */
																	               
#define DR0                    REGISTER_32(LPC_ADC_BASE + 0x010)    			   /*!< (@ 0x010) A/D Channel Data Register 0*/
#define DR1                    REGISTER_32(LPC_ADC_BASE + 0x014)    			   /*!< (@ 0x014) A/D Channel Data Register 1*/
#define DR2                    REGISTER_32(LPC_ADC_BASE + 0x018)    			   /*!< (@ 0x018) A/D Channel Data Register 2*/
#define DR3                    REGISTER_32(LPC_ADC_BASE + 0x01C)    			   /*!< (@ 0x01C) A/D Channel Data Register 3*/
#define DR4                    REGISTER_32(LPC_ADC_BASE + 0x020)    			   /*!< (@ 0x020) A/D Channel Data Register 4*/
#define DR5                    REGISTER_32(LPC_ADC_BASE + 0x024)    			   /*!< (@ 0x024) A/D Channel Data Register 5*/
#define DR6                    REGISTER_32(LPC_ADC_BASE + 0x028)    			   /*!< (@ 0x028) A/D Channel Data Register 6*/
#define DR7                    REGISTER_32(LPC_ADC_BASE + 0x02C)    			   /*!< (@ 0x02C) A/D Channel Data Register 7*/
																	               
#define STAT                   REGISTER_32(LPC_ADC_BASE + 0x030)    			   /*!< (@ 0x030) A/D Status Register.  */

/*------------- Flash-Control (FLASHCTRL) ----------------------------*/
			 
#define FLASHCFG               REGISTER_32(LPC_FLASH_EEPROM_CTRL_BASE + 0x010)     /*!< (@ 0x010) Flash memory access time configuration register */
                               
#define FMSSTART               REGISTER_32(LPC_FLASH_EEPROM_CTRL_BASE + 0x020)     /*!< (@ 0x020) Signature start address register */
#define FMSSTOP                REGISTER_32(LPC_FLASH_EEPROM_CTRL_BASE + 0x024)     /*!< (@ 0x024) Signature stop-address register */
                                                     
#define FMSW0                  REGISTER_32(LPC_FLASH_EEPROM_CTRL_BASE + 0x02C)     /*!< (@ 0x02C) Word 0 [31:0]          */
#define FMSW1                  REGISTER_32(LPC_FLASH_EEPROM_CTRL_BASE + 0x030)     /*!< (@ 0x030) Word 1 [63:32]         */
#define FMSW2                  REGISTER_32(LPC_FLASH_EEPROM_CTRL_BASE + 0x034)     /*!< (@ 0x034) Word 2 [95:64]         */
#define FMSW3                  REGISTER_32(LPC_FLASH_EEPROM_CTRL_BASE + 0x038)     /*!< (@ 0x038) Word 3 [127:96]        */
#define EEMSSTART 			   REGISTER_32(LPC_FLASH_EEPROM_CTRL_BASE + 0x09C)	   /*!< (@ 0x09C) EEPROM BIST start address register */
#define EEMSSTOP 			   REGISTER_32(LPC_FLASH_EEPROM_CTRL_BASE + 0x0A0)	   /*!< (@ 0x0A0) EEPROM BIST stop address register */
#define EEMSSIG 			   REGISTER_32(LPC_FLASH_EEPROM_CTRL_BASE + 0x0A4)	   /*!< (@ 0x0A4) EEPROM 24-bit BIST signature register*/
                                                  
#define FMSTAT                 REGISTER_32(LPC_FLASH_EEPROM_CTRL_BASE + 0xFE0)     /*!< (@ 0xFE0) Signature generation status register */
                                                      
#define FMSTATCLR              REGISTER_32(LPC_FLASH_EEPROM_CTRL_BASE + 0xFE8)     /*!< (@ 0xFE8) Signature generation status clear register */

/*------------- Nested-Vectored-Interrupt-Controller (NVIC) ----------------------------*/

#define ISER0                  REGISTER_32(LPC_NVIC_BASE + 0x100) 				   /*!< (@ 0x100) Interrupt Set Enable Register */
								 						 
#define ICER0                  REGISTER_32(LPC_NVIC_BASE + 0x180) 				   /*!< (@ 0x180) Interrupt Clear Enable Register */
								 						 
#define ISPR0                  REGISTER_32(LPC_NVIC_BASE + 0x200) 				   /*!< (@ 0x200) Interrupt Set Pending Register */
								 						 
#define ICPR0                  REGISTER_32(LPC_NVIC_BASE + 0x280) 				   /*!< (@ 0x280) Interrupt Clear Pending Register */

#define IABR0                  REGISTER_32(LPC_NVIC_BASE + 0x300) 				   /*!< (@ 0x300) Interrupt Active Bit Register */
								 																				 
#define IPR0                   REGISTER_32(LPC_NVIC_BASE + 0x400) 				   /*!< (@ 0x400) Interrupt Priority Register 0 */
#define IPR1                   REGISTER_32(LPC_NVIC_BASE + 0x404) 				   /*!< (@ 0x404) Interrupt Priority Register 1 */
#define IPR2                   REGISTER_32(LPC_NVIC_BASE + 0x408) 				   /*!< (@ 0x408) Interrupt Priority Register 2 */
#define IPR3                   REGISTER_32(LPC_NVIC_BASE + 0x40C) 				   /*!< (@ 0x40C) Interrupt Priority Register 3 */
#define IPR4                   REGISTER_32(LPC_NVIC_BASE + 0x410) 				   /*!< (@ 0x410) Interrupt Priority Register 4 */
#define IPR5                   REGISTER_32(LPC_NVIC_BASE + 0x414) 				   /*!< (@ 0x414) Interrupt Priority Register 5 */
#define IPR6                   REGISTER_32(LPC_NVIC_BASE + 0x418) 				   /*!< (@ 0x418) Interrupt Priority Register 6 */
#define IPR7                   REGISTER_32(LPC_NVIC_BASE + 0x41C) 				   /*!< (@ 0x41C) Interrupt Priority Register 7 */

